@@ -11,10 +11,14 @@
 module purge
 module load system/Python-3.7.4
 source env/bin/activate
-export PYTHONPATH=${PYTHONPATH}:"/path/to/solver/CPLEX_Studio1210/cplex/python/3.7/x86-64_linux"
+export PYTHONPATH=${PYTHONPATH}:"/path/to/solver/cplex/python/3.7/x86-64_linux"
+
+python dexom_python/gpr_rules.py -h
+# this prints all commandline parameters
 
 python dexom_python/gpr_rules.py -m example_data/recon2v2_corrected.json -g example_data/pval_0-01_geneweights.csv -o example_data/pval_0-01_reactionweights
 
 # this file can be used as an example for executing dexom_python functions on a slurm cluster
 # Note that the "path/to/solver" must be replaced by the folder where the CPLEX solver is actually installed
-# The example given here uses the gpr_rules.py script to convert gene expression values into reaction weights, see documentation for more possible functions
\ No newline at end of file
+# The example given here uses the gpr_rules.py script to convert gene expression values into continuous reaction weights
+# see documentation here: https://dexom-python.readthedocs.io/en/stable/dexom_python.html#module-dexom_python.gpr_rules
\ No newline at end of file
