@@ -1,4 +1,4 @@
-from .enumeration import EnumSolution
+from .enumeration import EnumSolution, read_prev_sol
 from .rxn_enum_functions import rxn_enum
 from .icut_functions import icut
 from .maxdist_functions import maxdist
