@@ -1,11 +1,12 @@
 import six
 import argparse
 import time
+import optlang
 from symengine import Add, sympify
 from numpy import abs
 from warnings import catch_warnings, filterwarnings, resetwarnings
 from cobra.exceptions import OptimizationError
-from dexom_python.model_functions import read_model, check_model_options, load_reaction_weights, check_threshold_tolerance
+from dexom_python.model_functions import read_model, check_model_options, load_reaction_weights, check_threshold_tolerance, check_constraint_primal_values
 from dexom_python.result_functions import write_solution
 from dexom_python.default_parameter_values import DEFAULT_VALUES
 
@@ -161,7 +162,9 @@ def imat(model, reaction_weights=None, epsilon=DEFAULT_VALUES['epsilon'], thresh
                 solution = model.optimize()
                 t2 = time.perf_counter()
                 print('%.2fs during optimize call' % (t2-t1))
-
+                if isinstance(model.solver, optlang.glpk_interface.Model):
+                    # during reaction-enumeration, GLPK sometimes returns invalid solutions
+                    check_constraint_primal_values(model)
                 return solution
             except UserWarning as w:
                 resetwarnings()
@@ -196,9 +199,10 @@ def _main():
     Use --help to see commandline parameters
     """
     description = 'Performs the modified iMAT algorithm with reaction weights'
-    parser = argparse.ArgumentParser(description=description, formatter_class=argparse.RawTextHelpFormatter)
-    parser.add_argument('-m', '--model', help='Metabolic model in sbml, json, or matlab format')
-    parser.add_argument('-r', '--reaction_weights', default={},
+    parser = argparse.ArgumentParser(description=description, formatter_class=argparse.ArgumentDefaultsHelpFormatter)
+    parser.add_argument('-m', '--model', default=argparse.SUPPRESS,
+                        help='Metabolic model in sbml, json, or matlab format')
+    parser.add_argument('-r', '--reaction_weights', default=argparse.SUPPRESS,
                         help='Reaction weights in csv format with column names: (reactions, weights)')
     parser.add_argument('-e', '--epsilon', type=float, default=DEFAULT_VALUES['epsilon'],
                         help='Activation threshold for highly expressed reactions')
