@@ -1,12 +1,13 @@
 import pandas as pd
-from dexom_python.model_functions import read_model, load_reaction_weights, check_model_options, DEFAULT_VALUES
+from dexom_python.model_functions import read_model, load_reaction_weights, check_model_options
+from dexom_python.default_parameter_values import DEFAULT_VALUES
 from dexom_python.result_functions import write_solution
 from dexom_python.imat_functions import imat
 from dexom_python.enum_functions.rxn_enum_functions import rxn_enum
 from dexom_python.enum_functions.diversity_enum_functions import diversity_enum
 
 
-def main():
+def _main():
     """
     This function is called when you run this script from the commandline.
     It performs iMAT, reaction-enumeration, and diversity-enumeration on a toy model
@@ -43,4 +44,4 @@ def main():
 
 
 if __name__ == '__main__':
-    main()
+    _main()
