@@ -155,8 +155,9 @@ def _main():
     Use --help to see commandline parameters
     """
     description = 'Performs pathway enrichment analysis using a hypergeometric test (Fischer exact test)'
-    parser = argparse.ArgumentParser(description=description, formatter_class=argparse.RawTextHelpFormatter)
-    parser.add_argument('-s', '--solutions', help='csv file containing enumeration solutions')
+    parser = argparse.ArgumentParser(description=description, formatter_class=argparse.ArgumentDefaultsHelpFormatter)
+    parser.add_argument('-s', '--solutions', default=argparse.SUPPRESS,
+                        help='csv file containing enumeration solutions')
     parser.add_argument('-m', '--model', default=None, help='Metabolic model in sbml, json, or matlab format, '
                                                             'required if subframe & sublist are absent')
     parser.add_argument('--sublist', default=None, help='List of all pathways/subsystems in the model')
